/*
 *  2014-09-12: this file was modified by International Business Machines Corporation.
 *  Modifications Copyright 2014 IBM Corporation.
 */

/*
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package java.beans;

import java.util.Collection;
import java.util.Iterator;

import org.apache.harmony.beans.BeansUtils;

class UtilCollectionPersistenceDelegate extends DefaultPersistenceDelegate {
	
	  @Override
	    protected void initialize(Class<?> type, Object oldInstance,
	            Object newInstance, Encoder enc) {
	        Collection<?> oldCollection = (Collection<?>) oldInstance;
	        Collection<?> newCollection = (Collection<?>) newInstance;
	        Iterator<?> oldIterator = oldCollection.iterator();
	        Object oldVal, newVal;
	        
	        if (newCollection.isEmpty()){
	        	while (oldIterator.hasNext()) {
		            oldVal = oldIterator.next();
		            if (oldVal != null){
		                enc.writeStatement(new Statement(oldInstance, BeansUtils.ADD,
		                        new Object[] { oldVal }));
		            }
		        }
	        } else {
	        	Object[] newArray = null;
	            int i = 0;
		        while (oldIterator.hasNext()) {
		            oldVal = oldIterator.next();
		            newArray = newCollection.toArray();
		            if(i < newArray.length){
		            	newVal = newArray[i];
		            } else{
		            	newVal = null;
		            }
		            i++;  
		            if (oldVal == null ? newVal != null : !enc.getPersistenceDelegate(
		                    oldVal.getClass()).mutatesTo(oldVal, newVal)) {
		                enc.writeStatement(new Statement(oldInstance, BeansUtils.ADD,
		                        new Object[] { oldVal }));
		            }
		        }
	        }

	    }

}
