/*
 *  2014-09-12: this file was modified by International Business Machines Corporation.
 *  Modifications Copyright 2014 IBM Corporation.
 */

/*
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package java.beans;

import java.util.List;

import org.apache.harmony.beans.BeansUtils;

class UtilListPersistenceDelegate extends DefaultPersistenceDelegate {

    @Override
    protected void initialize(Class<?> type, Object oldInstance,
            Object newInstance, Encoder enc) {
        List<?> oldList = (List<?>) oldInstance;
        int oldSize = oldList.size();
        Object[] newObjs = ((List<?>) newInstance).toArray();
        Expression oldExp;
        Object oldVal, newVal, cachedVal;
        for (int index = 0; index < oldSize; index++) {
            oldExp = new Expression(oldInstance, BeansUtils.GET,
                    new Object[] { index });
            // Calculate the old value of the property
            oldVal = enc.expressionValue(oldExp);
            // Write the getter expression to the encoder
            enc.writeExpression(oldExp);
            // Get the current property value in the new environment
            newVal = index < newObjs.length ? newObjs[index] : null;
            //consider null value maybe in list
            if (((cachedVal = enc.get(oldVal)) == null
                    || !enc.getPersistenceDelegate(cachedVal.getClass())
                            .mutatesTo(cachedVal, newVal))
                    && (oldVal != null || index >= newObjs.length)) {
                if (index < newObjs.length) {
                    enc.writeStatement(new Statement(oldInstance, BeansUtils.SET,
                        new Object[] { index, oldVal }));
                } else {
                    enc.writeStatement(new Statement(oldInstance, BeansUtils.ADD,
                        new Object[] { oldVal }));
                }
            }
        }
    }

}