/*
 *  2014-09-12: this file was modified by International Business Machines Corporation.
 *  Modifications Copyright 2014 IBM Corporation.
 */

/*
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package java.beans;

import java.util.Iterator;
import java.util.Map;

import org.apache.harmony.beans.BeansUtils;

class UtilMapPersistenceDelegate extends DefaultPersistenceDelegate {

    @Override
    protected void initialize(Class<?> type, Object oldInstance,
            Object newInstance, Encoder enc) {
        // Call the initialization of the super type
        super.initialize(type, oldInstance, newInstance, enc);

        Map<?, ?> oldMap = (Map<?, ?>) oldInstance;
        Map<?, ?> newMap = (Map<?, ?>) newInstance;
        Object key, oldVal, newVal, cachedVal;
        Expression oldExp;
        for (Iterator<?> keyIterator = oldMap.keySet().iterator(); keyIterator
                .hasNext();) {
            key = keyIterator.next();
            oldExp = new Expression(oldInstance, BeansUtils.GET,
                    new Object[] { key });
            oldVal = enc.expressionValue(oldExp);
            enc.writeExpression(oldExp);
            newVal = newMap.get(key);
            if ((cachedVal = enc.get(oldVal)) == null ? newVal != null : !enc
                    .getPersistenceDelegate(cachedVal.getClass()).mutatesTo(
                            cachedVal, newVal)) {
                enc.writeStatement(new Statement(oldInstance, BeansUtils.PUT,
                        new Object[] { key, oldVal }));
            }
        }
    }

}
