/*===========================================================================
 * Licensed Materials - Property of IBM
 * "Restricted Materials of IBM"
 * 
 * IBM SDK, Java(tm) Technology Edition, v6
 * (C) Copyright IBM Corp. 2013, 2014. All Rights Reserved
 *
 * US Government Users Restricted Rights - Use, duplication or disclosure
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 *===========================================================================
 */
/*
 * %W% %E%
 *
 * Copyright (c) 2006, Oracle and/or its affiliates. All rights reserved.
 * ORACLE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

package java.net;

import java.io.FileDescriptor;
import java.io.IOException;
import java.io.InterruptedIOException;
import java.security.PrivilegedAction;
import java.util.Enumeration;
import sun.net.ResourceManager;

/**
 * Concrete datagram and multicast socket implementation base class.
 * Note: This is not a public class, so that applets cannot call
 * into the implementation directly and hence cannot bypass the
 * security checks present in the DatagramSocket and MulticastSocket
 * classes.
 *
 * @author Pavani Diwanji
 */

class PlainDatagramSocketImpl extends DatagramSocketImpl
{
    /* timeout value for receive() */
    private int timeout = 0;
    private int trafficClass = 0;
    private boolean connected = false;
    private InetAddress connectedAddress = null;
    private int connectedPort = -1;

    /* cached socket options */
    private int multicastInterface = 0;
    private boolean loopbackMode = true;
    private int ttl = -1;
                                                                                //IBM-net_bringup
    /*JSE-4846 start*/                                                          //IBM-net_bringup
    /* number of threads using the FileDescriptor */                            //IBM-net_bringup
    private int fdUseCount = 0;                                                 //IBM-net_bringup
                                                                                //IBM-net_bringup
    /* indicates to use deferred close */                                       //IBM-net_bringup
    private boolean useDeferredClose = false;                                   //IBM-net_bringup
                                                                                //IBM-net_bringup
    /* lock when increment/decrementing fdUseCount */                           //IBM-net_bringup
    private Object fdLock = new Object();                                       //IBM-net_bringup

    /* indicates a close is pending on the file descriptor */                   //IBM-net_bringup
    private boolean closePending = false;                                       //IBM-net_bringup
    /*JSE-4846 end*/                                                            //IBM-net_bringup
                                                                                //IBM-net_bringup
    /* Used for IPv6 on Windows only */
    private FileDescriptor fd1;
    private int fduse=-1; /* saved between peek() and receive() calls */

    /* saved between successive calls to receive, if data is detected
     * on both sockets at same time. To ensure that one socket is not
     * starved, they rotate using this field
     */
    private int lastfd=-1; 

    /*
     * Needed for ipv6 on windows because we need to know
     * if the socket was bound to ::0 or 0.0.0.0, when a caller
     * asks for it. In this case, both sockets are used, but we
     * don't know whether the caller requested ::0 or 0.0.0.0
     * and need to remember it here.
     */
    private InetAddress anyLocalBoundAddr=null;

    /* the windows version. */
    private static float version;

    /* sun.net.useExclusiveBind */
    private static String exclBindProp;

    /* True if exclusive binding is on for Windows */
    private static boolean exclusiveBind;

    /*
     * Set to true if SO_REUSEADDR is set after the socket is bound to
     * indicate SO_REUSEADDR is being emulated
     */
    private boolean reuseAddressEmulated;

    // emulates SO_REUSEADDR when exclusiveBind is true and socket is bound
    private boolean isReuseAddress;

    /**
     * Load net library into runtime.
     */
    static {
	java.security.AccessController.doPrivileged(
		  new sun.security.action.LoadLibraryAction("net"));
	init();
        java.security.AccessController.doPrivileged( new PrivilegedAction<Object>() {
             public Object run() {
                if (System.getProperties().getProperty("os.name").startsWith("Windows"))
                    version = Float.parseFloat(System.getProperties().getProperty("os.version").split("\\s")[0]); //IBM-net_bringup
                exclBindProp = System.getProperty("sun.net.useExclusiveBind");
                return null;
            }
        });

        if (version > 0.0 && exclBindProp != null) { 
            // sun.net.useExclusiveBind is set
            exclusiveBind = exclBindProp.length() == 0 ? true: Boolean.parseBoolean(exclBindProp); 
        } else if (version >= 6.0) {
            exclusiveBind = true;
        }
    }

    /**
     * Creates a datagram socket
     */
    protected synchronized void create() throws SocketException {
	fd = new FileDescriptor();
	fd1 = new FileDescriptor();
        ResourceManager.beforeUdpCreate();
        try {
	    datagramSocketCreate();
        } catch (SocketException ioe) {
            ResourceManager.afterUdpClose();
            fd = null;
            fd1 = null;
            throw ioe;
        }
    }

    /**
     * Binds a datagram socket to a local port.
     */
    protected synchronized void bind(int lport, InetAddress laddr) 
        throws SocketException {
	
	bind0(lport, laddr, exclusiveBind);
	if (laddr.isAnyLocalAddress()) {
	    anyLocalBoundAddr = laddr;
	}
    }

    protected synchronized native void bind0(int lport, InetAddress laddr,
                                             boolean exclBind)
        throws SocketException;

    /**
     * Sends a datagram packet. The packet contains the data and the
     * destination address to send the packet to.
     * @param packet to be sent.
     */
    /*JSE-4846 start*/                                                          //IBM-net_bringup
    protected void send(DatagramPacket P) throws IOException                    //IBM-net_bringup
    {                                                                           //IBM-net_bringup
	FileDescriptor fd0 = acquireFD();                                       //IBM-net_bringup
	try{                                                                    //IBM-net_bringup
		send0(P);                                                       //IBM-net_bringup
	}finally{                                                               //IBM-net_bringup
		releaseFD();                                                    //IBM-net_bringup
	}                                                                       //IBM-net_bringup
    }                                                                           //IBM-net_bringup
    /*JSE-4846 end*/                                                            //IBM-net_bringup

    protected native void send0(DatagramPacket p) throws IOException;	   //IBM-net_bringup
                                                                                //IBM-net_bringup
    /**
     * Connects a datagram socket to a remote destination. This associates the remote
     * address with the local socket so that datagrams may only be sent to this destination
     * and received from this destination.
     * @param address the remote InetAddress to connect to
     * @param port the remote port number
     */
    protected void connect(InetAddress address, int port) throws SocketException {
	connect0(address, port);
	connectedAddress = address;
	connectedPort = port;
	connected = true;
    }

    /**
     * Disconnects a previously connected socket. Does nothing if the socket was
     * not connected already.
     */
    protected void disconnect() {
	disconnect0(connectedAddress.holder().getFamily());
	connected = false;
	connectedAddress = null;
	connectedPort = -1;
    }

    /**
     * Peek at the packet to see who it is from.
     * @param return the address which the packet came from.
     */
    protected synchronized native int peek(InetAddress i) throws IOException;
    protected synchronized native int peekData(DatagramPacket p) throws IOException;

    protected synchronized void bind0(int lport, InetAddress laddr)
        throws SocketException
    {
        bind0(lport, laddr, exclusiveBind);

    }

    /**
     * Receive the datagram packet.
     * @param Packet Received.
     */
    protected synchronized void receive(DatagramPacket p) 
        throws IOException {
	/*JSE-4846 start*/                                                      //IBM-net_bringup
	FileDescriptor fd0 = acquireFD();                                       //IBM-net_bringup
	try {
	    receive0(p);
	} finally {
	    fduse = -1;
	    releaseFD();                                                        //IBM-net_bringup
	}
	/*JSE-4846 end*/                                                        //IBM-net_bringup
    }

    protected synchronized native void receive0(DatagramPacket p)
        throws IOException;
	                                                                        //IBM-net_bringup
    /*JSE-4846 start*/                                                          //IBM-net_bringup
    /*                                                                          //IBM-net_bringup
     * "Acquires" and returns the FileDescriptor for this impl                  //IBM-net_bringup
     *                                                                          //IBM-net_bringup
     * A corresponding releaseFD is required to "release" the                   //IBM-net_bringup
     * FileDescriptor.                                                          //IBM-net_bringup
     */                                                                         //IBM-net_bringup
    private final FileDescriptor acquireFD(){                                   //IBM-net_bringup
   	synchronized(fdLock){                                                //IBM-net_bringup
		fdUseCount++;                                                   //IBM-net_bringup
    		return fd;                                                  //IBM-net_bringup
	}                                                                       //IBM-net_bringup
    }                                                                           //IBM-net_bringup
                                                                                //IBM-net_bringup
    /*                                                                          //IBM-net_bringup
     * "Release" the FileDescriptor for this impl.                              //IBM-net_bringup
     *                                                                          //IBM-net_bringup
     * If the use count goes to -1 then the socket is closed.                   //IBM-net_bringup
     */                                                                         //IBM-net_bringup
    private final void releaseFD(){                                             //IBM-net_bringup
	synchronized(fdLock){                                                   //IBM-net_bringup
		fdUseCount--;                                                   //IBM-net_bringup
		if(fdUseCount == -1){                                           //IBM-net_bringup
			if(fd!=null){                                           //IBM-net_bringup
				useDeferredClose=false;                         //IBM-net_bringup
				datagramSocketClose();                          //IBM-net_bringup
				fd=null;                                        //IBM-net_bringup
			}                                                       //IBM-net_bringup
		}                                                               //IBM-net_bringup
	}                                                                       //IBM-net_bringup
    }                                                                           //IBM-net_bringup
    /*JSE-4846 end*/                                                            //IBM-net_bringup
                                                                                //IBM-net_bringup

    /**
     * Set the TTL (time-to-live) option.
     * @param TTL to be set.
     */
    protected native void setTimeToLive(int ttl) throws IOException;

    /**
     * Get the TTL (time-to-live) option.
     */
    protected native int getTimeToLive() throws IOException;

    /**
     * Set the TTL (time-to-live) option.
     * @param TTL to be set.
     */
    protected native void setTTL(byte ttl) throws IOException;

    /**
     * Get the TTL (time-to-live) option.
     */
    protected native byte getTTL() throws IOException;

    /**
     * Join the multicast group.
     * @param multicast address to join.
     */
    protected void join(InetAddress inetaddr) throws IOException {
	join(inetaddr, null);
    }

    /**
     * Leave the multicast group.
     * @param multicast address to leave.
     */
    protected void leave(InetAddress inetaddr) throws IOException {
	leave(inetaddr, null);
    }
    /**
     * Join the multicast group.
     * @param multicast address to join.
     * @param netIf specifies the local interface to receive multicast
     *        datagram packets
     * @throws  IllegalArgumentException if mcastaddr is null or is a
     *          SocketAddress subclass not supported by this socket
     * @since 1.4
     */

    protected void joinGroup(SocketAddress mcastaddr, NetworkInterface netIf)
	throws IOException {
	if (mcastaddr == null || !(mcastaddr instanceof InetSocketAddress))
	    throw new IllegalArgumentException("Unsupported address type");
	join(((InetSocketAddress)mcastaddr).getAddress(), netIf);
    }

    private native void join(InetAddress inetaddr, NetworkInterface netIf)
	throws IOException;

    /**
     * Leave the multicast group.
     * @param multicast address to leave.
     * @param netIf specified the local interface to leave the group at
     * @throws  IllegalArgumentException if mcastaddr is null or is a
     *          SocketAddress subclass not supported by this socket
     * @since 1.4
     */
    protected void leaveGroup(SocketAddress mcastaddr, NetworkInterface netIf)
	throws IOException {
	if (mcastaddr == null || !(mcastaddr instanceof InetSocketAddress))
	    throw new IllegalArgumentException("Unsupported address type");
	leave(((InetSocketAddress)mcastaddr).getAddress(), netIf);
    }

    private native void leave(InetAddress inetaddr, NetworkInterface netIf)
	throws IOException;

    /**
     * Close the socket.
     */
    protected void close() {
       /*JSE-4846 start*/                                                       //IBM-net_bringup
       synchronized(fdLock){                                                    //IBM-net_bringup
            if (fd != null || fd1 != null) {                                    //IBM-net_bringup
                if (fdUseCount ==0) {                                           //IBM-net_bringup
                    closePending = true;                                        //IBM-net_bringup
                    /*                                                          //IBM-net_bringup
                     * We close the FileDescriptor in two-steps - first the     //IBM-net_bringup
                     * "pre-close" which closes the socket but doesn't          //IBM-net_bringup
                     * release the underlying file descriptor. This operation   //IBM-net_bringup
                     * may be lengthy due to untransmitted data and a long      //IBM-net_bringup
                     * linger interval. Once the pre-close is done we do the    //IBM-net_bringup
                     * actual socket to release the fd.                         //IBM-net_bringup
                     */                                                         //IBM-net_bringup
                    try{                                                        //IBM-net_bringup
                       useDeferredClose=true;                                   //IBM-net_bringup
                       datagramSocketClose();                                   //IBM-net_bringup
                   } finally{                                                   //IBM-net_bringup
                       useDeferredClose=false;                                  //IBM-net_bringup
                       datagramSocketClose();                                   //IBM-net_bringup
                   }                                                            //IBM-net_bringup
                   ResourceManager.afterUdpClose();                             //IBM-net_bringup
                   fd = null;                                                   //IBM-net_bringup
                   fd1 = null;                                                  //IBM-net_bringup
                   return;                                                      //IBM-net_bringup
                } else {                                                        //IBM-net_bringup
                   /*                                                           //IBM-net_bringup
                     * If a thread has acquired the fd and a close              //IBM-net_bringup
                     * isn't pending then use a deferred close.                 //IBM-net_bringup
                     * Also decrement fdUseCount to signal the last             //IBM-net_bringup
                     * thread that releases the fd to close it.                 //IBM-net_bringup
                     */                                                         //IBM-net_bringup
                     if (!closePending) {                                       //IBM-net_bringup
                        closePending = true;                                    //IBM-net_bringup
                        fdUseCount--;                                           //IBM-net_bringup
                        useDeferredClose=true;                                  //IBM-net_bringup
                        datagramSocketClose();                                  //IBM-net_bringup
                   }                                                            //IBM-net_bringup
                }                                                               //IBM-net_bringup
            }                                                                   //IBM-net_bringup
	}
       /*JSE-4846 end*/                                                         //IBM-net_bringup
    }

    protected void finalize() {
	close();
    }

    /**
     * set a value - since we only support (setting) binary options
     * here, o must be a Boolean
     */

     public void setOption(int optID, Object o) throws SocketException {
         if (fd == null && fd1 == null) {
            throw new SocketException("Socket Closed");
         }
	 switch (optID) {
	    /* check type safety b4 going native.  These should never
	     * fail, since only java.Socket* has access to
	     * PlainSocketImpl.setOption().
	     */
	 case SO_TIMEOUT:
	     if (o == null || !(o instanceof Integer)) {
		 throw new SocketException("bad argument for SO_TIMEOUT");
	     }
	     int tmp = ((Integer) o).intValue();
	     if (tmp < 0)
		 throw new IllegalArgumentException("timeout < 0");
	     timeout = tmp;
	     return;
	 case IP_TOS:
	     if (o == null || !(o instanceof Integer)) {
		 throw new SocketException("bad argument for IP_TOS");
	     }
	     trafficClass = ((Integer)o).intValue();
	     break;
	 case SO_REUSEADDR:
	     if (o == null || !(o instanceof Boolean)) {
		 throw new SocketException("bad argument for SO_REUSEADDR");
	     }
	     break;
	 case SO_BROADCAST:
	     if (o == null || !(o instanceof Boolean)) {
		 throw new SocketException("bad argument for SO_BROADCAST");
	     }
	     break;
	 case SO_BINDADDR:
	     throw new SocketException("Cannot re-bind Socket");
	 case SO_RCVBUF:
	 case SO_SNDBUF:
	     if (o == null || !(o instanceof Integer) ||
		 ((Integer)o).intValue() < 0) {
		 throw new SocketException("bad argument for SO_SNDBUF or " +
					   "SO_RCVBUF");
	     }
	     break;
	 case IP_MULTICAST_IF:
	     if (o == null || !(o instanceof InetAddress))
		 throw new SocketException("bad argument for IP_MULTICAST_IF");
	     break;
	 case IP_MULTICAST_IF2:
	     if (o == null || !(o instanceof NetworkInterface))
		 throw new SocketException("bad argument for IP_MULTICAST_IF2");
	     break;
	 case IP_MULTICAST_LOOP:
	     if (o == null || !(o instanceof Boolean))
		 throw new SocketException("bad argument for IP_MULTICAST_LOOP");
	     break;
	 default:
	     throw new SocketException("invalid option: " + optID);
	 }
	 socketSetOption(optID, o);
     }

    /*
     * get option's state - set or not
     */

    public Object getOption(int optID) throws SocketException {
        if (fd == null && fd1 == null) {
            throw new SocketException("Socket Closed");
        }

        if (optID == SO_REUSEADDR && reuseAddressEmulated) {
            return isReuseAddress;
        }

	Object result;

	switch (optID) {
	    case SO_TIMEOUT:
		result = new Integer(timeout);
		break;
	
	    case IP_TOS:
		result = socketGetOption(optID);
		if ( ((Integer)result).intValue() == -1) {
		    result = new Integer(trafficClass);
		}
		break;

	    case SO_BINDADDR:
		if (fd != null && fd1 != null) {
		    return anyLocalBoundAddr;	
		}
		/* fall through */
	    case IP_MULTICAST_IF:
	    case IP_MULTICAST_IF2:
	    case SO_RCVBUF:
	    case SO_SNDBUF:
	    case IP_MULTICAST_LOOP:
	    case SO_REUSEADDR:
	    case SO_BROADCAST:
		result = socketGetOption(optID);
		break;

	    default:
		throw new SocketException("invalid option: " + optID);
  	}

	return result;
    }

    protected void socketSetOption(int opt, Object val)
        throws SocketException
    {
        if (opt == SO_REUSEADDR && exclusiveBind && localPort != 0)  {
            // socket already bound, emulate
            reuseAddressEmulated = true;
            isReuseAddress = (Boolean)val;
        } else {
            socketNativeSetOption(opt, val);
        }
    }

    private native void datagramSocketCreate() throws SocketException;
    private native void datagramSocketClose();
    private native void socketNativeSetOption(int opt, Object val)
        throws SocketException;
    private native Object socketGetOption(int opt) throws SocketException;

    private native void connect0(InetAddress address, int port) throws SocketException;
    private native void disconnect0(int family);

    /**
     * Perform class load-time initializations.
     */
    native int dataAvailable();
    private native static void init();

}

//IBM-net_bringup
